import { 
  select, 
  csv , 
  scaleTime, 
  scaleLinear,
  extent, 
  max,
  scalePoint, 
  axisLeft,
  axisBottom,
  area,
  format,
  curveBasis
} from 'd3'; 

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data => {
  const title = 'World Population';
  
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.population;
  const yAxisLabel = 'Population';
  
 //const margin = { top: 50, right: 40, bottom: 90, left: 150};
  const margin = { top: 60, right: 40, bottom: 88, left: 105};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 6; 

  
  
        
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([-70, innerWidth])
  	.nice();
  
  // scale Band is for the height of the bar charts
  const yScale = scaleLinear() 
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0])
		.nice();
  
    
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  

  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.ticks(6)
  	.tickPadding(15);
  
  const yAxisTickFormat = number => 
  	format('.1s')(number)
  		.replace('G','B');
  
	const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  	.tickFormat(yAxisTickFormat);
  
  //yAxis(g.append('g'));
const yAxisG =  g.append('g')
	yAxisG.call(yAxis)
  			.selectAll('.domain')  // .tick line removes the y axis lines
  			.remove();
  
	
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.attr('x', -innerHeight/2)
  	.attr('y', -60)
  	.attr('transform', `rotate(-90)`)
    .style('text-anchor', 'middle')
    .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();  // .tick line removes the y axis lines
  		
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.attr('x', innerWidth/2)
  	.attr('y', 75)
    .text(xAxisLabel);
  

  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis); // instead of lines between point we use spline
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', areaGenerator(data));

  
    
  g.selectAll('circle').data(data) // data join of rect elements and data, which is the csv
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx',  d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
	svg.append('text')
  	.attr('class', 'title')
  	.attr('x', width/2)
  	.attr('y', +50)
  	.text(title);



}; 

csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data => {
    data.forEach(d => { // parsing code here
      console.log(data);
      d.population = +d.population;
      d.year = new Date(d.year);
    });
    render(data);
  });